@@ -134,8 +134,8 @@ class Cellpose():
 
         channels: list (optional, default None)
             list of channels, either of length 2 or of length number of images by 2.
-            First element of list is the channel to segment (0=grayscale, 1=red, 2=blue, 3=green).
-            Second element of list is the optional nuclear channel (0=none, 1=red, 2=blue, 3=green).
+            First element of list is the channel to segment (0=grayscale, 1=red, 2=green, 3=blue).
+            Second element of list is the optional nuclear channel (0=none, 1=red, 2=green, 3=blue).
             For instance, to segment grayscale images, input [0,0]. To segment images with cells
             in green and nuclei in blue, input [2,3]. To segment one grayscale image and one
             image with cells in green and nuclei in blue, input [[0,0], [2,3]].
@@ -370,8 +370,8 @@ class CellposeModel(UnetModel):
 
             channels: list (optional, default None)
                 list of channels, either of length 2 or of length number of images by 2.
-                First element of list is the channel to segment (0=grayscale, 1=red, 2=blue, 3=green).
-                Second element of list is the optional nuclear channel (0=none, 1=red, 2=blue, 3=green).
+                First element of list is the channel to segment (0=grayscale, 1=red, 2=green, 3=blue).
+                Second element of list is the optional nuclear channel (0=none, 1=red, 2=green, 3=blue).
                 For instance, to segment grayscale images, input [0,0]. To segment images with cells
                 in green and nuclei in blue, input [2,3]. To segment one grayscale image and one
                 image with cells in green and nuclei in blue, input [[0,0], [2,3]].
@@ -491,12 +491,12 @@ class CellposeModel(UnetModel):
                 if progress is not None:
                     progress.setValue(55)
                 styles.append(style)
+                if resample:
+                    y = transforms.resize_image(y, shape[-3], shape[-2])
+                cellprob = y[:,:,-1]
+                dP = y[:,:,:2].transpose((2,0,1))
                 if compute_masks:
                     tic=time.time()
-                    if resample:
-                        y = transforms.resize_image(y, shape[-3], shape[-2])
-                    cellprob = y[:,:,-1]
-                    dP = y[:,:,:2].transpose((2,0,1))
                     niter = 1 / rescale[i] * 200
                     p = dynamics.follow_flows(-1 * dP * (cellprob > cellprob_threshold) / 5., 
                                                 niter=niter, interp=interp, use_gpu=self.gpu)
@@ -514,7 +514,7 @@ class CellposeModel(UnetModel):
                     masks.append(maski)
                     flow_time += time.time() - tic
                 else:
-                    flows.append([None]*3)
+                    flows.append([dx_to_circ(dP), dP, cellprob, []])
                     masks.append([])
             if compute_masks:
                 print('time spent: running network %0.2fs; flow+mask computation %0.2f'%(net_time, flow_time))
@@ -695,8 +695,8 @@ class SizeModel():
 
             channels: list (optional, default None)
                 list of channels, either of length 2 or of length number of images by 2.
-                First element of list is the channel to segment (0=grayscale, 1=red, 2=blue, 3=green).
-                Second element of list is the optional nuclear channel (0=none, 1=red, 2=blue, 3=green).
+                First element of list is the channel to segment (0=grayscale, 1=red, 2=green, 3=blue).
+                Second element of list is the optional nuclear channel (0=none, 1=red, 2=green, 3=blue).
                 For instance, to segment grayscale images, input [0,0]. To segment images with cells
                 in green and nuclei in blue, input [2,3]. To segment one grayscale image and one
                 image with cells in green and nuclei in blue, input [[0,0], [2,3]].
